---  
layout: fr  
title: OPENENET-MS01-MoneroSpace-Decentralized-Satellite-Network  
author: OPENENET Team  
date: April 13, 2025  
amount: 30000  
milestones:  
  - name: Satellite Node Hardware Design & Team Formation  
    funds: 7000  
    done: false  
    status: unfinished  
  - name: Radiation-Hardened Node Software Development & Compliance Preparation  
    funds: 8000  
    done: false  
    status: unfinished  
  - name: Satellite Prototype Testing & Spectrum Application  
    funds: 10000  
    done: false  
    status: unfinished  
  - name: Community Testnet Launch & First Deployment  
    funds: 5000  
    done: false  
    status: unfinished  
payouts:  
  - date: 2025-09-30  
    amount: 7000  
  - date: 2026-03-31  
    amount: 8000  
  - date: 2026-09-30  
    amount: 10000  
  - date: 2027-03-31  
    amount: 5000  
---  


# OPENENET-MS01-MoneroSpace-Decentralized-Satellite-Network  

**Proposal ID:** OPENENET-MS01  
- **Project Repository:** [https://git.openenet.cn/MoneroSpace](https://git.openenet.cn/MoneroSpace)  
- **Collaboration Platform:** [https://cloud.openenet.cn/](https://cloud.openenet.cn/)  
- **Project Funding Deadline:** December 28, 2035, 00:00 UTC. Unused funds will be returned to CCS if the project is incomplete by this date.  


## 1. Project Overview  
### 1.1 Core Objectives  
MoneroSpace aims to build a **decentralized censorship-resistant satellite communication network** through open-source hardware and encryption protocols, achieving:  
- **Global Ubiquitous Access**: Providing Monero transaction channels for regions without terrestrial networks (e.g., oceans, polar areas) and censored zones (e.g., Iran, Syria).  
- **Physical-Layer Censorship Resistance**: Bypassing internet blockades with low-earth orbit (LEO) satellites to ensure independent transaction broadcasting.  
- **Community-Driven Ecosystem**: Open-sourcing satellite hardware designs and communication protocols to enable third-party node deployment.  

### 1.2 Core Values  
| Dimension    | Innovation                                                                 | Contribution to Monero Ecosystem                  |  
|--------------|----------------------------------------------------------------------------|------------------------------------------------|  
| **Technical** | Laser-RF hybrid communication and radiation-hardened full-node design       | Enhances network redundancy against 51% attacks and geographic blockades |  
| **Compliance**| Neutral-region ground station deployment and ITU spectrum compliance       | Meets international telecommunication regulations and data privacy standards |  
| **Economic**  | Satellite node mining incentives and transaction fee sharing model         | Establishes a sustainable decentralized infrastructure economy         |  


## 2. Technical Solution  
### 2.1 Satellite Node Hardware Architecture (3U CubeSat Standard)  
#### 2.1.2 Hardware Design Resources  
- Motherboard Layout: [/MoneroSpace](https://git.openenet.cn/MoneroSpace)  
- Antenna Deployment Mechanism: [/MoneroSpace](https://git.openenet.cn/MoneroSpace)  

### 2.2 Communication System Design  
#### 2.2.1 Three-Layer Communication Architecture  
```mermaid  
graph TB  
    subgraph User Layer  
        A[User Terminal] -->|UHF 400-470MHz| B[Satellite Node]  
    end  
    subgraph Satellite Layer  
        B -->|Laser 1550nm| C[Neighbor Satellite 1]  
        B -->|Laser 1550nm| D[Neighbor Satellite 2]  
        C -->|Laser 1550nm| E[Ground Station]  
        D -->|S-Band 2-4GHz| E  
    end  
    subgraph Ground Layer  
        E[Neutral Ground Station] -->|Tor Network| F[Monero Mainnet]  
    end  
```  
- **User Access**:  
  - Terminal modification: Compatible with commercial satellite terminals (e.g., Starlink Dish), integrated with radiation-hardened encryption modules (ChaCha20-Poly1305 algorithm).  
  - Dynamic frequency hopping: 128 frequency points with 10-second interval switching, combined with satellite-side frequency prediction to achieve 45% improved anti-jamming success rate.  
- **Inter-Satellite Communication**:  
  - Laser links: Randomly select 2 neighboring satellites for data forwarding, adding 30% dummy transactions to obfuscate transmission paths (anonymity set expanded 5x).  
  - RF links: Serve as emergency channels during laser outages, using DVB-S2X standard and AES-256-GCM encryption with latency < 500ms.  
- **Ground Access**:  
  - Ground stations located in neutral regions (Zug, Switzerland & Reykjavik, Iceland), each equipped with 5 radiation-hardened servers running Monero full nodes.  
  - Access to the mainnet via 3-hop Tor relays, achieving 99.9% node IP anonymity.  


## 6. Community Engagement Plan  
### 6.1 Open-Source Collaboration  
- **Hardware Design**: All CAD drawings and BOM lists are open-sourced on Gitea under the CERN-OHL protocol, enabling third-party modification.  
- **Protocol Development**: Laser communication code is released under the MIT protocol, welcoming community contributions.  
  - Repository: [https://git.openenet.cn/MoneroSpace](https://git.openenet.cn/MoneroSpace) (Under Development)  

### 6.3 Transparency Assurance  
- **Progress Tracking**: Weekly updates on development progress are posted to the Gitea repository.  


## 7. Proposer Information (Preparation Phase)  
### 7.1 Current Status  
- **Community Certification**: Applying for Monero Community Developer Certification (MCC), expected to complete in Q3 2025.  
- **Collaboration Platforms**: Gitea and Nextcloud are under preparation; send resumes to admin@openenet.cn to apply for collaboration access.  
- **Communication Channel**:  
  - Email: admin@openenet.cn  


## 8. Expected Delivery Results
### 8.1. Satellite Node Hardware Design & Team Formation (7,000 XMR)  
- **Deliverables**:  
- Finalized 3U CubeSat hardware design package including:  
- Detailed CAD drawings of the satellite structure  
- Bill of Materials (BOM) with radiation-hardened component specifications  
- Selection report for radiation-resistant processors, memory, and storage  
- Public announcement of the core team with:  
- At least 5 members with proven expertise in aerospace engineering or blockchain development  
- Verified professional profiles (LinkedIn/community contributions)  
- Fully initialized Gitea repository with:  
- Open-source hardware design templates  
- Version control system for iterative design updates  

- **Success Metrics**:  
- Minimum 5 independent technical reviews from certified aerospace consultants (reports published on Gitea)   


### 8.2. Radiation-Hardened Node Software Development & Compliance Preparation (8,000 XMR)  
- **Deliverables**:  
- Working prototype of the Monero node software optimized for satellite hardware, featuring:  
- Memory/processing efficiency improvements for low-power space environments  
- Public GitHub commit history demonstrating code progress  
- Draft submission package for ITU spectrum allocation, including:  
- Frequency usage plan for laser/RF communication links  
- Proposed satellite orbit parameters (altitude, inclination, orbital period)  
- Compliance checklist for international telecommunication regulations  
- Risk assessment report for software resilience, covering:  
- Strategies to mitigate single-event upsets (SEU) in space radiation  
- Redundancy plans for critical node functions  

- **Success Metrics**:  
- Minimum 10 code contributions from external developers (tracked on GitHub)  
- Official confirmation email from ITU频谱 regulatory experts acknowledging consultation  


### 8.3. Satellite Prototype Testing & Spectrum Application (10,000 XMR)  
- **Deliverables**:  
- Lab-tested satellite prototype demonstrating:  
- 72-hour stability in thermal vacuum chambers (-55°C to +85°C) with test data logs  
- Radiation tolerance exceeding 100krad total dose (certified by independent testing lab)  
- Formal submission of ITU spectrum application, with:  
- Publicly shared application ID and filing date  
- Confirmation of receipt from the ITU Radiocommunication Bureau  
- Updated compliance framework document outlining:  
- GDPR/Switzerland FDP data protection protocols for ground station operations  
- Cybersecurity measures for satellite-ground communication  

- **Success Metrics**:  
- Publicly released video showcasing prototype testing procedures and results  
- Uploaded ITU receipt document to the CCS project update page  


### 8.4. Community Testnet Launch & First Deployment Plan (5,000 XMR)  
- **Deliverables**:  
- Functional community testnet enabling:  
- Over 100 developers to simulate satellite-node interactions (transaction routing, orbit dynamics)  
- Open API for third-party node integration  
- Detailed deployment plan for the first 3 satellites, including:  
- Chosen orbital slots and launch window feasibility study  
- Ground station locations (Switzerland/Iceland) with site readiness reports  
- Revised economic model document explaining:  
- Transaction fee distribution for node operators  
- Incentive structures for community contributors  

- **Success Metrics**:  
- Active participation from 50+ developers in testnet stress tests  
- Signed memorandum of understanding (MOU) with at least one reputable launch provider (e.g., Star River Power or SpaceX)  


## 9. Conclusion  
The MoneroSpace project focuses on **open-source collaboration** to address Monero's physical-layer censorship resistance needs. Despite preparation-phase challenges, our transparent development process, community-driven incentives, and robust technical solutions aim to build a decentralized satellite communication infrastructure.  


**Proposer:** OPENENET Team  
**Date:** April 13, 2025  